@@ -1,6 +1,7 @@
-"""watch-fs is a command line tool to run commands when files change"""
+# -*- coding: utf8 -*-
+"""watch-fs is a command line tool to run commands when files change."""
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import datetime
 import subprocess
@@ -9,28 +10,8 @@ import click
 import pyinotify
 
 
-@click.command()
-@click.option(
-    '--directory', '-d', 'directories', multiple=True, default=['.'],
-    type=click.Path(dir_okay=True, file_okay=True, exists=True),
-    help="A directory to watch for file changes - can be used multiple times, "
-    "and defaults to the current directory.")
-@click.option(
-    '-c', '--clear', is_flag=True,
-    help="Clear the terminal before running the command")
-@click.option(
-    '-w', '--wait', type=click.FLOAT, default=1,
-    help="A minium wait before running the command again, in seconds")
-@click.option(
-    '-v', '--verbose', 'verbosity', count=True,
-    help="-v prints commands before running, and -vv shows debug information")
-@click.argument('command')
-def main(directories, clear, wait, verbosity, command):
-    WatchFS(directories, command, clear, wait, verbosity).run()
-
-
 class Timer(object):
-    """Calls a function if a delay has passed since the last successful call"""
+    """Call a function if a delay has passed since the last successful call."""
 
     @staticmethod
     def now():
@@ -41,26 +22,29 @@ class Timer(object):
         self.finished_at = self.now() - self.wait
 
     def ready(self):
-        """Returns True if .wait has passed since .finished_at"""
+        """Return True if ``wait`` has passed since ``finished_at``."""
         return (self.now() - self.finished_at) > self.wait
 
     def finished(self):
-        """Resets the finished_at attribute"""
+        """Reset ``finished_at``."""
         self.finished_at = self.now()
 
 
-class WatchFS(pyinotify.ProcessEvent):
-    def __init__(self, directories, command, clear, wait, verbosity,
+class WatchFS(object):
+    """A timer and pyinotify setup to run a command when files change."""
+
+    def __init__(self, directories, command, clear, show, verbose, wait,
                  mask=pyinotify.IN_CREATE | pyinotify.IN_MODIFY):
         self.directories = directories
         self.command = command
         self.clear = clear
-        self.verbosity = verbosity
+        self.show = show
+        self.verbose = verbose
         self.mask = mask
         self.timer = Timer(wait)
 
     def run(self):
-        """Setup inotify to call run_command() on each event"""
+        """Setup inotify to call run_command() on each event."""
         watch_manager = pyinotify.WatchManager()
         for d in self.directories:
             watch_manager.add_watch(d, self.mask, rec=True, auto_add=True)
@@ -70,25 +54,44 @@ class WatchFS(pyinotify.ProcessEvent):
         notifier.loop()
 
     def maybe_run_command(self, event):
-        """Run the command *if* the delay has passed"""
+        """Run the command if the delay has passed."""
         if self.timer.ready():
-            self.say(2, '!', 'Ready, running command')
             self.run_command()
             self.timer.finished()
-        else:
-            self.say(2, '!', 'Not ready, skipping event')
 
     def run_command(self):
         if self.clear:
-            subprocess.call('clear')
-        self.say(1, '$', self.command)
+            click.clear()
+        if self.show:
+            click.secho('$ {0}'.format(self.command), fg='cyan')
         exit_code = subprocess.call(self.command, shell=True)
-        self.say(2, "!", "Command '{}' exited with code {}".format(
+        if self.verbose:
+            click.echo("! Command '{0}' exited [{1}]".format(
                 self.command, exit_code))
 
-    def say(self, verbosity, *args, **kwargs):
-        if self.verbosity >= verbosity:
-            print(*args, **kwargs)
+
+@click.command()
+@click.option(
+    '--directory', '-d', 'directories', multiple=True, default=['.'],
+    type=click.Path(dir_okay=True, file_okay=True, exists=True),
+    help="A directory to watch for file changes - can be used multiple times, "
+    "and defaults to the current directory.")
+@click.option(
+    '-c', '--clear/--no-clear', is_flag=True, default=True,
+    help="Clear the terminal before running the command.")
+@click.option(
+    '-s', '--show/--no-show', is_flag=True, default=True,
+    help="Show commands before runnning them.")
+@click.option(
+    '-v', '--verbose/--no-verbose', is_flag=True, default=False,
+    help="Show exit codes.")
+@click.option(
+    '-w', '--wait', type=click.FLOAT, default=1,
+    help="A minium wait between commands, in seconds.")
+@click.argument('command', nargs=-1)
+def main(command, **kwargs):
+    """Click entry point for watch-fs."""
+    WatchFS(command=' '.join(command), **kwargs).run()
 
 if __name__ == '__main__':
     main()
